=======
History
=======

0.1.5 (2020-09-05)
------------------

* Fix issue in the cli interface.

0.1.4 (2020-09-04)
------------------

* Change development status to alpha.
* Fix deploy issue.
* Include the json data file in distribution.


0.1.3 (2020-09-02)
------------------

* Fix deploy issue.


0.1.2 (2020-09-02)
------------------

* Update README and documentation.
* Traslate the documentation to spanish.
* Fix another deploy issue.

0.1.1 (2020-08-31)
------------------

* Fix deploy issue.


0.1.0 (2020-08-30)
------------------

* First release on PyPI.
* Electoral roll feature.